@@ -1,4 +1,10 @@
 
+as.mlt <- function(object)
+    UseMethod("as.mlt")
+
+as.mlt.mlt <- function(object)
+    object
+
 weights.mlt <- function(object, ...) {
     if (!is.null(object$weights))
         return(object$weights)
@@ -41,7 +47,12 @@ vcov.mlt <- function(object, parm = coef(object, fixed = FALSE), ...)
     solve(Hessian(object, parm = parm))
 
 logLik.mlt <- function(object, parm = coef(object, fixed = FALSE), 
-                       w = weights(object), ...) {
+                       w = weights(object), newdata, ...) {
+    if (!missing(newdata)) {
+        tmpmod <- mlt(object$model, data = newdata, dofit = FALSE)
+        coef(tmpmod) <- coef(object)
+        return(logLik(tmpmod))
+    }
     ret <- -object$loglik(parm, weights = w)
     ###    attr(ret, "df") <- length(coef(object, fixed = FALSE))
     attr(ret, "df") <- object$df
@@ -60,7 +71,7 @@ mkgrid.ctm <- function(object, n = n, ...)
     mkgrid(object$model, n = n, ...)
 
 variable.names.mlt <- function(object, ...)
-    variable.names(object$model)
+    variable.names(object$model, ...)
 
 model <- function(object)
     UseMethod("model")
